==> nitobe-6.x-2.6.tar.gz: nitobe/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.13 2009/02/11 20:06:30 shannonlucas Exp $

//----------------------------------------------------------------------------
// Some variables to make some of the code easier to read.
$nitobe_rendered_name   = nitobe_alt_word_text(check_plain($site_name));
$nitobe_render_date     = !empty($node) && nitobe_show_datestamp($node->type);
$nitobe_primary_links   = isset($primary_links)   ? 
                          theme('links', $primary_links, array('id' => 'topLinks', 'class' => 'grid_16')) : NULL;
$nitobe_secondary_links = isset($secondary_links) ? 
                          theme('links', $secondary_links, array('id' => 'subLinks', 'class' => 'links secondary-links grid_16')) : NULL;

if ($nitobe_has_sidebar) {
  $nitobe_headline_class = "headline grid_12 alpha";
  $nitobe_title_class    = "grid_8 alpha";
  $nitobe_author_class   = "node-author grid_12 alpha";
  $nitobe_center_class   = "grid_12";
}
else {
  $nitobe_headline_class = "headline grid_16 alpha";
  $nitobe_title_class    = "grid_12 alpha";
  $nitobe_author_class   = "node-author grid_16";
  $nitobe_center_class   = "grid_16";
}
?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
    <title><?php print $head_title ?></title>
    <?php print $head ?>
    <?php print $styles ?>
    <?php print $scripts ?>
    <!--[if IE]>
      <?php print phptemplate_get_ie_styles() . "\n"; ?>
    <![endif]-->
  </head>
  <body class="<?php print $body_classes; ?>">
    <div id="page" class="container_16">
      <div id="header">
        <div id="headerTitle" class="grid_12">
          <?php if (isset($logo)): ?>
            <a href="<?php print check_url($front_page); ?>" title="<?php print check_plain($site_name); ?>"><img src="<?php print check_url($logo); ?>" alt="<?php print $site_title; ?>" id="logo" /></a>
          <?php endif; ?>
          <div id="title-wrapper" style="float: left;">
            <h1><a href="<?php print check_url($front_page); ?>" title="<?php print check_plain($site_name); ?>"><?php print $nitobe_rendered_name; ?></a></h1>
            <?php if (isset($site_slogan)): ?>
              <div id="site-slogan"><?php print check_plain($site_slogan); ?></div>
            <?php endif; ?>
          </div> <!-- /#title-wrapper -->
        </div> <!-- /#headerTitle -->
        <div id="search-top" class="grid_4"><?php if ($search_box) { print $search_box; } ?></div>
        <div class="clear"></div>
        <?php if ($header): ?><div id="top-header" class="grid_16"><?php print $header; ?></div><div class="clear"></div><?php endif; ?>
        <div id="headerLinks" class="grid_16">
          <?php if (!empty($nitobe_primary_links)) { print $nitobe_primary_links; } ?>
          <?php if (!empty($nitobe_secondary_links)) : ?>
            <div class="clear"></div>
            <?php print $nitobe_secondary_links; ?>
          <?php endif; ?>
        </div><!-- #headerLinks -->
        <div class="clear"></div>
        <div id="masthead" class="grid_16"><?php if (!empty($masthead)) { print $masthead; } ?></div>
      </div><!-- /#header -->
      <div class="rule-top">&nbsp;</div>
      <?php if ($mission): ?><div id="mission" class="grid_16"><?php print $mission; ?></div><?php endif; ?>
      <div id="center" class="<?php print $nitobe_center_class; ?>">
        <?php print $breadcrumb; ?>
        <?php if (!empty($title)): ?>
          <div class="<?php print $nitobe_headline_class; ?>">
            <?php print '<h2 class="'. ($tabs ? 'with-tabs ' : ' ') . $nitobe_title_class . '">'. $title .'</h2>'; ?>
            <?php if ($nitobe_render_date): ?>
              <div class="timestamp grid_4 omega"><?php print format_date($node->created, 'custom', 'd M Y'); ?></div>
            <?php endif; ?>
          </div><!-- #headline -->
          <div class="clear"></div>
        <?php endif; ?>
        <?php if (!empty($tabs)):?>
            <div id="tabs-wrapper" class="grid_12 alpha">
                <ul class="tabs primary"><?php print $tabs; ?></ul>
                <?php if ($tabs2): ?>
                    <ul class="tabs secondary"><?php print $tabs2; ?></ul>
                <?php endif; ?>
            </div>
            <div class="clear"></div>
        <?php endif; ?>
        <?php if ($show_messages && $messages): print $messages; endif; ?>
        <?php print $help; ?>
        <?php print $content ?>
        <div class="clear"></div>
      </div> <!-- /#center -->
      <?php if (isset($right) || isset($left)): ?>
        <div id="sidebar-right" class="sidebar grid_4">
          <?php
            //-----------------------------------------------------------------
            // $left is printed here in case the previous theme had blocks in
            // the 'left' region. This would be the case if switching from
            // Garland which places the navigation block in the 'left' region.
            if (isset($left)) print $left;
            if (isset($right)) print $right;
          ?>
        </div><!-- /#sidebar-right -->
      <?php endif; ?>
      <div class="clear">&nbsp;</div>
      <?php if ($bottom): ?>
        <div id="bottomPad">&nbsp;</div>
        <div id="bottom-hr" class="rule">&nbsp;</div>
        <div id="bottom" class="grid_16">
          <div id="bottom-bar">
            <?php print $bottom; ?>
          </div>
        </div>
        <div class="clear">&nbsp;</div>
        <br />
      <?php endif; ?>
      <div class="rule">&nbsp;</div>
      <div id="footer">
        <?php print $footer_message . $footer ?>
      </div>
    </div> <!-- /#page -->
  <?php print $closure; ?>
  </body>
</html>

==> nitobe-6.x-3.1.tar.gz: nitobe/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.13.4.1 2009/03/01 13:02:29 shannonlucas Exp $
//----------------------------------------------------------------------------
// Some variables to make some of the code easier to read.
$nitobe_rendered_name   = nitobe_alt_word_text(check_plain($site_name));
$nitobe_render_date     = !empty($node) && nitobe_show_datestamp($node->type);
$nitobe_primary_links   = isset($primary_links)   ?
                          theme('links', $primary_links, array('id' => 'topLinks', 'class' => 'grid_16')) : NULL;
$nitobe_secondary_links = isset($secondary_links) ?
                          theme('links', $secondary_links, array('id' => 'subLinks', 'class' => 'links secondary-links grid_16')) : NULL;

if ($nitobe_has_sidebar) {
  $nitobe_headline_class = "headline grid_12 alpha";
  $nitobe_title_class    = "grid_8 alpha";
  $nitobe_author_class   = "node-author grid_12 alpha";
  $nitobe_center_class   = "grid_12";
}
else {
  $nitobe_headline_class = "headline grid_16 alpha";
  $nitobe_title_class    = "grid_12 alpha";
  $nitobe_author_class   = "node-author grid_16";
  $nitobe_center_class   = "grid_16";
}
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>">
  <head>
    <title><?php print $head_title ?></title>
    <?php print $head ?>
    <?php print $styles ?>
    <?php print $scripts ?>
    <!--[if gte IE]>
      <link type="text/css" rel="stylesheet" media="screen" href="<?php print base_path() . path_to_theme(); ?>/fix-ie.css" />
      <?php if (defined('LANGUAGE_RTL') && $language->direction == LANGUAGE_RTL): ?>
        <style type="text/css" media="screen">@import "<?php print base_path() . path_to_theme(); ?>/fix-ie-rtl.css";</style>
      <?php endif; ?>
    <![endif]-->
    <!--[if lt IE 7]>
      <link type="text/css" rel="stylesheet" media="screen" href="<?php print base_path() . path_to_theme(); ?>/fix-ie6.css" />
      <?php if (defined('LANGUAGE_RTL') && $language->direction == LANGUAGE_RTL): ?>
        <style type="text/css" media="screen">@import "<?php print base_path() . path_to_theme(); ?>/fix-ie6-rtl.css";</style>
      <?php endif; ?>
    <![endif]-->
  </head>
  <body class="<?php print $body_classes; ?>">
    <div id="page" class="container_16">
      <div id="header">
        <div id="headerTitle" class="grid_12">
          <?php if (isset($logo)): ?>
            <a href="<?php print check_url($front_page); ?>" title="<?php print check_plain($site_name); ?>"><img src="<?php print check_url($logo); ?>" alt="<?php print $site_title; ?>" id="logo" /></a>
          <?php endif; ?>
          <div id="title-wrapper">
            <h1><a href="<?php print check_url($front_page); ?>" title="<?php print check_plain($site_name); ?>"><?php print $nitobe_rendered_name; ?></a></h1>
            <?php if (isset($site_slogan)): ?>
              <div id="site-slogan"><?php print check_plain($site_slogan); ?></div>
            <?php endif; ?>
          </div> <!-- /#title-wrapper -->
        </div> <!-- /#headerTitle -->
        <div id="search-top" class="grid_4"><?php if ($search_box) { print $search_box; } ?></div>
        <div class="clear"></div>
        <?php if ($header): ?><div id="top-header" class="grid_16"><?php print $header; ?></div><div class="clear"></div><?php endif; ?>
        <div id="headerLinks" class="grid_16">
          <?php if (!empty($nitobe_primary_links)) { print $nitobe_primary_links; } ?>
          <?php if (!empty($nitobe_secondary_links)) : ?>
            <div class="clear"></div>
            <?php print $nitobe_secondary_links; ?>
          <?php endif; ?>
        </div><!-- #headerLinks -->
        <div class="clear"></div>
        <div id="masthead" class="grid_16"><?php if (!empty($masthead)) { print $masthead; } ?></div>
      </div><!-- /#header -->
      <div class="rule-top">&nbsp;</div>
      <?php if ($mission): ?><div id="mission" class="grid_16"><?php print $mission; ?></div><?php endif; ?>
      <div id="center" class="<?php print $nitobe_center_class; ?>">
        <?php print $breadcrumb; ?>
        <?php if (!empty($title)): ?>
          <div class="<?php print $nitobe_headline_class; ?>">
            <?php print '<h2 class="'. ($tabs ? 'with-tabs ' : '') . $nitobe_title_class . '">'. $title .'</h2>'; ?>
            <?php if ($nitobe_render_date): ?>
              <div class="timestamp grid_4 omega"><?php print format_date($node->created, 'custom', 'd M Y'); ?></div>
            <?php endif; ?>
          </div><!-- #headline -->
          <div class="clear"></div>
        <?php endif; ?>
        <?php if (!empty($tabs)):?>
            <div id="tabs-wrapper" class="grid_12 alpha">
                <ul class="tabs primary"><?php print $tabs; ?></ul>
                <?php if ($tabs2): ?>
                    <ul class="tabs secondary"><?php print $tabs2; ?></ul>
                <?php endif; ?>
            </div>
            <div class="clear"></div>
        <?php endif; ?>
        <?php if ($show_messages && $messages): print $messages; endif; ?>
        <?php print $help; ?>
        <?php print $content ?>
        <div class="clear"></div>
      </div> <!-- /#center -->
      <?php if (isset($right) || isset($left)): ?>
        <div id="sidebar-right" class="sidebar grid_4">
          <?php
            //-----------------------------------------------------------------
            // $left is printed here in case the previous theme had blocks in
            // the 'left' region. This would be the case if switching from
            // Garland which places the navigation block in the 'left' region.
            if (isset($left)) print $left;
            if (isset($right)) print $right;
          ?>
        </div><!-- /#sidebar-right -->
      <?php endif; ?>
      <div class="clear">&nbsp;</div>
      <?php if ($bottom): ?>
        <div id="bottomPad">&nbsp;</div>
        <div id="bottom-hr" class="rule">&nbsp;</div>
        <div id="bottom" class="grid_16">
          <div id="bottom-bar">
            <?php print $bottom; ?>
          </div>
        </div>
        <div class="clear">&nbsp;</div>
        <br />
      <?php endif; ?>
      <div class="rule">&nbsp;</div>
      <div id="footer">
        <?php print $footer_message . $footer ?>
      </div>
    </div> <!-- /#page -->
  <?php print $closure; ?>
  </body>
</html>
